INSTAGRAM_FEED = """
{
    "created_time": "2015-10-10T10:30:00Z",
    "user": {
            "full_name": "Kevin S",
            "id": "3",
            "profile_picture": "http://distillery.s3.amazonaws.com/profiles/profile_3_75sq_1295574122.jpg",
            "username": "kevin"
        },
    "posts": [
        {
            "caption": "",
            "comment_count": 2,
            "created_time": "2015-01-01T11:00:00Z",
            "id": "123456789",
            "image": {
                "height": 612,
                "url": "http://distilleryimage2.ak.instagram.com/11f75f1cd9cc11e2a0fd22000aa8039a_7.jpg",
                "width": 612
            },
            "like_count": 1,
            "tags": [
                "example", "tag"
            ],
            "type": "image",
            "user": {
                "full_name": "Kevin S",
                "id": "3",
                "profile_picture": "http://distillery.s3.amazonaws.com/profiles/profile_3_75sq_1295574122.jpg",
                "username": "kevin"
            }
        },
        {
            "caption": "Inside le truc #foodtruck",
            "comment_count": 0,
            "created_time": "2015-01-01T11:00:00Z",
            "id": "123456789",
            "image": {
                "height": 612,
                "url": "http://distillery.s3.amazonaws.com/media/2011/02/02/6ea7baea55774c5e81e7e3e1f6e791a7_7.jpg",
                "width": 612
            },
            "like_count": 15,
            "tags": [
                "foodtruck"
            ],
            "type": "image",
            "user": {
                "full_name": "Kevin S",
                "id": "3",
                "profile_picture": "http://distillery.s3.amazonaws.com/profiles/profile_3_75sq_1295574122.jpg",
                "username": "kevin"
            }
        }
    ]
}
"""

TWITTER_FEED = """
[
    {
        "created_at": "Thu Apr 06 15:28:43 +0000 2017",
        "id": 850007368138018817,
        "id_str": "850007368138018817",
        "text": "RT @TwitterDev: 1/ Today we’re sharing our vision for the future of the Twitter API platform!nhttps://t.co/XweGngmxlP",
        "truncated": false,
        "entities": {
            "hashtags": [
            ],
            "symbols": [
            ],
            "user_mentions": [
                {
                    "screen_name": "TwitterDev",
                    "name": "TwitterDev",
                    "id": 2244994945,
                    "id_str": "2244994945",
                    "indices": [
                        3,
                        14
                    ]
                }
            ],
            "urls": [
                {
                    "url": "https://t.co/XweGngmxlP",
                    "expanded_url": "https://cards.twitter.com/cards/18ce53wgo4h/3xo1c",
                    "display_url": "cards.twitter.com/cards/18ce53wg…",
                    "indices": [
                        94,
                        117
                    ]
                }
            ]
        },
        "source": "<a href='http://twitter.com' rel='nofollow'>Twitter Web Client</a>",
        "in_reply_to_status_id": null,
        "in_reply_to_status_id_str": null,
        "in_reply_to_user_id": null,
        "in_reply_to_user_id_str": null,
        "in_reply_to_screen_name": null,
        "user": {
            "id": 6253282,
            "id_str": "6253282",
            "name": "Twitter API",
            "screen_name": "twitterapi",
            "location": "San Francisco, CA",
            "description": "The Real Twitter API. I tweet about API changes, service issues and happily answer questions about Twitter and our API. Don't get an answer? It's on my website.",
            "url": "http://t.co/78pYTvWfJd",
            "entities": {
                "url": {
                    "urls": [
                        {
                            "url": "http://t.co/78pYTvWfJd",
                            "expanded_url": "https://dev.twitter.com",
                            "display_url": "dev.twitter.com",
                            "indices": [
                                0,
                                22
                            ]
                        }
                    ]
                },
                "description": {
                    "urls": [
                    ]
                }
            },
            "protected": false,
            "followers_count": 6172353,
            "friends_count": 46,
            "listed_count": 13091,
            "created_at": "Wed May 23 06:01:13 +0000 2007",
            "favourites_count": 26,
            "utc_offset": -25200,
            "time_zone": "Pacific Time (US & Canada)",
            "geo_enabled": true,
            "verified": true,
            "statuses_count": 3583,
            "lang": "en",
            "contributors_enabled": false,
            "is_translator": false,
            "is_translation_enabled": false,
            "profile_background_color": "C0DEED",
            "profile_background_image_url": "http://pbs.twimg.com/profile_background_images/656927849/miyt9dpjz77sc0w3d4vj.png",
            "profile_background_image_url_https": "https://pbs.twimg.com/profile_background_images/656927849/miyt9dpjz77sc0w3d4vj.png",
            "profile_background_tile": true,
            "profile_image_url": "http://pbs.twimg.com/profile_images/2284174872/7df3h38zabcvjylnyfe3_normal.png",
            "profile_image_url_https": "https://pbs.twimg.com/profile_images/2284174872/7df3h38zabcvjylnyfe3_normal.png",
            "profile_banner_url": "https://pbs.twimg.com/profile_banners/6253282/1431474710",
            "profile_link_color": "0084B4",
            "profile_sidebar_border_color": "C0DEED",
            "profile_sidebar_fill_color": "DDEEF6",
            "profile_text_color": "333333",
            "profile_use_background_image": true,
            "has_extended_profile": false,
            "default_profile": false,
            "default_profile_image": false,
            "following": true,
            "follow_request_sent": false,
            "notifications": false,
            "translator_type": "regular"
        },
        "geo": null,
        "coordinates": null,
        "place": null,
        "contributors": null,
        "retweeted_status": {
            "created_at": "Thu Apr 06 15:24:15 +0000 2017",
            "id": 850006245121695744,
            "id_str": "850006245121695744",
            "text": "1/ Today we’re sharing our vision for the future of the Twitter API platform!nhttps://t.co/XweGngmxlP",
            "truncated": false,
            "entities": {
                "hashtags": [
                ],
                "symbols": [
                ],
                "user_mentions": [
                ],
                "urls": [
                    {
                        "url": "https://t.co/XweGngmxlP",
                        "expanded_url": "https://cards.twitter.com/cards/18ce53wgo4h/3xo1c",
                        "display_url": "cards.twitter.com/cards/18ce53wg…",
                        "indices": [
                            78,
                            101
                        ]
                    }
                ]
            },
            "source": "<a href='http://twitter.com' rel='nofollow'>Twitter Web Client</a>",
            "in_reply_to_status_id": null,
            "in_reply_to_status_id_str": null,
            "in_reply_to_user_id": null,
            "in_reply_to_user_id_str": null,
            "in_reply_to_screen_name": null,
            "user": {
                "id": 2244994945,
                "id_str": "2244994945",
                "name": "TwitterDev",
                "screen_name": "TwitterDev",
                "location": "Internet",
                "description": "Your official source for Twitter Platform news, updates & events. Need technical help? Visit https://t.co/mGHnxZCxkt ⌨️  #TapIntoTwitter",
                "url": "https://t.co/66w26cua1O",
                "entities": {
                    "url": {
                        "urls": [
                            {
                                "url": "https://t.co/66w26cua1O",
                                "expanded_url": "https://dev.twitter.com/",
                                "display_url": "dev.twitter.com",
                                "indices": [
                                    0,
                                    23
                                ]
                            }
                        ]
                    },
                    "description": {
                        "urls": [
                            {
                                "url": "https://t.co/mGHnxZCxkt",
                                "expanded_url": "https://twittercommunity.com/",
                                "display_url": "twittercommunity.com",
                                "indices": [
                                    93,
                                    116
                                ]
                            }
                        ]
                    }
                },
                "protected": false,
                "followers_count": 465425,
                "friends_count": 1523,
                "listed_count": 1168,
                "created_at": "Sat Dec 14 04:35:55 +0000 2013",
                "favourites_count": 2098,
                "utc_offset": -25200,
                "time_zone": "Pacific Time (US & Canada)",
                "geo_enabled": true,
                "verified": true,
                "statuses_count": 3031,
                "lang": "en",
                "contributors_enabled": false,
                "is_translator": false,
                "is_translation_enabled": false,
                "profile_background_color": "FFFFFF",
                "profile_background_image_url": "http://abs.twimg.com/images/themes/theme1/bg.png",
                "profile_background_image_url_https": "https://abs.twimg.com/images/themes/theme1/bg.png",
                "profile_background_tile": false,
                "profile_image_url": "http://pbs.twimg.com/profile_images/530814764687949824/npQQVkq8_normal.png",
                "profile_image_url_https": "https://pbs.twimg.com/profile_images/530814764687949824/npQQVkq8_normal.png",
                "profile_banner_url": "https://pbs.twimg.com/profile_banners/2244994945/1396995246",
                "profile_link_color": "0084B4",
                "profile_sidebar_border_color": "FFFFFF",
                "profile_sidebar_fill_color": "DDEEF6",
                "profile_text_color": "333333",
                "profile_use_background_image": false,
                "has_extended_profile": false,
                "default_profile": false,
                "default_profile_image": false,
                "following": true,
                "follow_request_sent": false,
                "notifications": false,
                "translator_type": "regular"
            },
            "geo": null,
            "coordinates": null,
            "place": null,
            "contributors": null,
            "is_quote_status": false,
            "retweet_count": 284,
            "favorite_count": 399,
            "favorited": false,
            "retweeted": false,
            "possibly_sensitive": false,
            "lang": "en"
        },
        "is_quote_status": false,
        "retweet_count": 284,
        "favorite_count": 0,
        "favorited": false,
        "retweeted": false,
        "possibly_sensitive": false,
        "lang": "en"
    },
    {
        "created_at": "Mon Apr 03 16:09:50 +0000 2017",
        "id": 848930551989915648,
        "id_str": "848930551989915648",
        "text": "RT @TwitterMktg: Starting today, businesses can request and share locations when engaging with people in Direct Messages. https://t.co/rpYn…",
        "truncated": false,
        "entities": {
            "hashtags": [
            ],
            "symbols": [
            ],
            "user_mentions": [
                {
                    "screen_name": "TwitterMktg",
                    "name": "Twitter Marketing",
                    "id": 357750891,
                    "id_str": "357750891",
                    "indices": [
                        3,
                        15
                    ]
                }
            ],
            "urls": [
            ]
        },
        "source": "<a href='http://twitter.com' rel='nofollow'>Twitter Web Client</a>",
        "in_reply_to_status_id": null,
        "in_reply_to_status_id_str": null,
        "in_reply_to_user_id": null,
        "in_reply_to_user_id_str": null,
        "in_reply_to_screen_name": null,
        "user": {
            "id": 6253282,
            "id_str": "6253282",
            "name": "Twitter API",
            "screen_name": "twitterapi",
            "location": "San Francisco, CA",
            "description": "The Real Twitter API. I tweet about API changes, service issues and happily answer questions about Twitter and our API. Don't get an answer? It's on my website.",
            "url": "http://t.co/78pYTvWfJd",
            "entities": {
                "url": {
                    "urls": [
                        {
                            "url": "http://t.co/78pYTvWfJd",
                            "expanded_url": "https://dev.twitter.com",
                            "display_url": "dev.twitter.com",
                            "indices": [
                                0,
                                22
                            ]
                        }
                    ]
                },
                "description": {
                    "urls": [

                    ]
                }
            },
            "protected": false,
            "followers_count": 6172353,
            "friends_count": 46,
            "listed_count": 13091,
            "created_at": "Wed May 23 06:01:13 +0000 2007",
            "favourites_count": 26,
            "utc_offset": -25200,
            "time_zone": "Pacific Time (US & Canada)",
            "geo_enabled": true,
            "verified": true,
            "statuses_count": 3583,
            "lang": "en",
            "contributors_enabled": false,
            "is_translator": false,
            "is_translation_enabled": false,
            "profile_background_color": "C0DEED",
            "profile_background_image_url": "http://pbs.twimg.com/profile_background_images/656927849/miyt9dpjz77sc0w3d4vj.png",
            "profile_background_image_url_https": "https://pbs.twimg.com/profile_background_images/656927849/miyt9dpjz77sc0w3d4vj.png",
            "profile_background_tile": true,
            "profile_image_url": "http://pbs.twimg.com/profile_images/2284174872/7df3h38zabcvjylnyfe3_normal.png",
            "profile_image_url_https": "https://pbs.twimg.com/profile_images/2284174872/7df3h38zabcvjylnyfe3_normal.png",
            "profile_banner_url": "https://pbs.twimg.com/profile_banners/6253282/1431474710",
            "profile_link_color": "0084B4",
            "profile_sidebar_border_color": "C0DEED",
            "profile_sidebar_fill_color": "DDEEF6",
            "profile_text_color": "333333",
            "profile_use_background_image": true,
            "has_extended_profile": false,
            "default_profile": false,
            "default_profile_image": false,
            "following": true,
            "follow_request_sent": false,
            "notifications": false,
            "translator_type": "regular"
        },
        "geo": null,
        "coordinates": null,
        "place": null,
        "contributors": null,
        "retweeted_status": {
            "created_at": "Mon Apr 03 16:05:05 +0000 2017",
            "id": 848929357519241216,
            "id_str": "848929357519241216",
            "text": "Starting today, businesses can request and share locations when engaging with people in Direct Messages. https://t.co/rpYndqWfQw",
            "truncated": false,
            "entities": {
                "hashtags": [
                ],
                "symbols": [
                ],
                "user_mentions": [
                ],
                "urls": [
                    {
                        "url": "https://t.co/rpYndqWfQw",
                        "expanded_url": "https://cards.twitter.com/cards/5wzucr/3x700",
                        "display_url": "cards.twitter.com/cards/5wzucr/3…",
                        "indices": [
                            105,
                            128
                        ]
                    }
                ]
            },
            "source": "<a href='https://ads.twitter.com' rel='nofollow'>Twitter Ads</a>",
            "in_reply_to_status_id": null,
            "in_reply_to_status_id_str": null,
            "in_reply_to_user_id": null,
            "in_reply_to_user_id_str": null,
            "in_reply_to_screen_name": null,
            "user": {
                "id": 357750891,
                "id_str": "357750891",
                "name": "Twitter Marketing",
                "screen_name": "TwitterMktg",
                "location": "Twitter HQ ",
                "description": "Twitter’s place for marketers, agencies, and creative thinkers ⭐ Bringing you insights, news, updates, and inspiration. Visit @TwitterAdsHelp for Ads support.",
                "url": "https://t.co/Tfo4moo92y",
                "entities": {
                    "url": {
                        "urls": [
                            {
                                "url": "https://t.co/Tfo4moo92y",
                                "expanded_url": "https://marketing.twitter.com",
                                "display_url": "marketing.twitter.com",
                                "indices": [
                                    0,
                                    23
                                ]
                            }
                        ]
                    },
                    "description": {
                        "urls": [

                        ]
                    }
                },
                "protected": false,
                "followers_count": 924546,
                "friends_count": 661,
                "listed_count": 3893,
                "created_at": "Thu Aug 18 21:08:15 +0000 2011",
                "favourites_count": 1934,
                "utc_offset": -25200,
                "time_zone": "Pacific Time (US & Canada)",
                "geo_enabled": true,
                "verified": true,
                "statuses_count": 6329,
                "lang": "en",
                "contributors_enabled": false,
                "is_translator": false,
                "is_translation_enabled": false,
                "profile_background_color": "C0DEED",
                "profile_background_image_url": "http://pbs.twimg.com/profile_background_images/662767273/jvmxdpdrplhxcw8yvkv2.png",
                "profile_background_image_url_https": "https://pbs.twimg.com/profile_background_images/662767273/jvmxdpdrplhxcw8yvkv2.png",
                "profile_background_tile": true,
                "profile_image_url": "http://pbs.twimg.com/profile_images/800953549697888256/UlXXL5h5_normal.jpg",
                "profile_image_url_https": "https://pbs.twimg.com/profile_images/800953549697888256/UlXXL5h5_normal.jpg",
                "profile_banner_url": "https://pbs.twimg.com/profile_banners/357750891/1487188210",
                "profile_link_color": "19CF86",
                "profile_sidebar_border_color": "FFFFFF",
                "profile_sidebar_fill_color": "DDEEF6",
                "profile_text_color": "333333",
                "profile_use_background_image": true,
                "has_extended_profile": false,
                "default_profile": false,
                "default_profile_image": false,
                "following": false,
                "follow_request_sent": false,
                "notifications": false,
                "translator_type": "none"
            },
            "geo": null,
            "coordinates": null,
            "place": null,
            "contributors": null,
            "is_quote_status": false,
            "retweet_count": 111,
            "favorite_count": 162,
            "favorited": false,
            "retweeted": false,
            "possibly_sensitive": false,
            "lang": "en"
        },
        "is_quote_status": false,
        "retweet_count": 111,
        "favorite_count": 0,
        "favorited": false,
        "retweeted": false,
        "lang": "en"
    }
]"""

RSS = b"""
<?xml version="1.0" encoding="utf-8" ?>
<feed xmlns="http://www.w3.org/2005/Atom">
  <title>Pellentesque Tortor</title>
  <link href="https://signagewidgets.net/samples/rss.xml" />
  <entry>
    <id>6</id>
    <title>Fusce Ligula Egestas Vestibulum</title>
    <content>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec sed odio dui egestas eget quam.</content>
    <link rel="enclosure" type="image/jpeg" href="https://signagewidgets.net/samples/1.jpg" />
    <published>2021-08-30T10:45:12Z</published>
  </entry>
  <entry>
    <id>1</id>
    <title>Ligula Amet Venenatis Consectetur</title>
    <content>Donec ullamcorper nulla non metus auctor fringilla. Vestibulum id ligula porta felis euismod semper.</content>
    <link rel="enclosure" type="image/jpeg" href="https://signagewidgets.net/samples/2.jpg" />
    <published>2021-08-30T14:17:51Z</published>
  </entry>
  <entry>
    <id>10</id>
    <title>Condimentum Purus Commodo, donec ullamcorper nulla non metus auctor fringilla</title>
    <content>Aenean lacinia bibendum nulla sed consectetur. Fusce dapibus, tellus ac cursus commodo, ut fermentum massa justo sit amet risus.</content>
    <link rel="enclosure" type="image/jpeg" href="https://signagewidgets.net/samples/3.jpg" />
    <published>2021-08-30T15:20:30Z</published>
  </entry>
  <entry>
    <id>4</id>
    <title>Parturient Nibh Mattis Vestibulum</title>
    <content>Cras justo odio, dapibus ac facilisis in, egestas eget quam. Integer posuere erat a ante venenatis dapibus posuere velit aliquet.</content>
    <published>2021-08-30T15:20:30Z</published>
  </entry>
  <entry>
    <id>5</id>
    <title>Ridiculus Tellus Magna</title>
    <published>2021-08-30T15:20:30Z</published>
  </entry>
  <entry>
    <id>7</id>
    <title>Fusce Ligula Egestas Vestibulum</title>
    <link rel="enclosure" type="image/jpeg" href="https://signagewidgets.net/samples/4.jpg" />
    <published>2021-08-30T10:45:12Z</published>
  </entry>
  <entry>
    <id>8</id>
    <content>Cras justo odio, dapibus ac facilisis in, egestas eget quam. Integer posuere erat a ante venenatis dapibus posuere velit aliquet.</content>
    <link rel="enclosure" type="image/jpeg" href="https://signagewidgets.net/samples/5.jpg" />
    <published>2021-08-30T10:45:12Z</published>
  </entry>
  <entry>
    <id>9</id>
    <link rel="enclosure" type="image/jpeg" href="https://signagewidgets.net/samples/6.jpg" />
    <published>2021-08-30T10:45:12Z</published>
  </entry>
</feed>
"""

VIDEOS = [
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/1.mp4",
        "duration": 48.693,
        "width": 720,
        "height": 720,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/2.mp4",
        "duration": 54.73,
        "width": 720,
        "height": 720,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/3.mp4",
        "duration": 17.067,
        "width": 640,
        "height": 640,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/4.mp4",
        "duration": 16.05,
        "width": 1920,
        "height": 1080,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/5.mp4",
        "duration": 15.723,
        "width": 1920,
        "height": 1080,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/6.mp4",
        "duration": 27.904,
        "width": 1920,
        "height": 1080,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/7.mp4",
        "duration": 55.126,
        "width": 1080,
        "height": 1920,
    },
    {
        "type": "video",
        "url": "https://signagewidgets.net/samples/8.mp4",
        "duration": 10.07,
        "width": 640,
        "height": 640,
    },
]

PLAYBACK_INFO = """{
  "reason": {
    "type": "scheduled"
  },
  "campaign": {
    "id": "vPHxEp",
    "name": "content name",
    "duration": 20,
    "tags": [
      "content tag 1",
      "contenttag2"
    ],
    "attrs": {
      "attr 1": "value 1"
    }
  },
  "player": {
    "id": "8BCYL6A",
    "name": "player name",
    "version": "10.0.5",
    "tags": [
      "player tag 1",
      "playertag2"
    ],
    "attrs": {
      "attr 1": 1,
      "attr 2": "value 2"
    }
  }
}"""

PLAYBACK_LOOP = """{
  "ts": 1702061023000,
  "loops": [
    {
      "name": "PRIMARY",
      "start": 1702060000000,
      "content": {
        "id": "__simulator__",
        "playId": "#c444",
        "kind": "APP",
        "name": "app-name",
        "attrs": {},
        "reason": "LOOP",
        "start": 1702061023000
      }
    }
  ]
}"""

AIRPORT_DATA = """
{
  "name": "",
  "localtime": "",
  "updated_at": "",
  "departures": [
    {
      "location": "Asunci\u00f3n",
      "time": "2024-02-07T16:00:00-03:00",
      "estimated_time": "2024-02-07T16:00:00-03:00",
      "status": "Scheduled",
      "terminal": "",
      "gate": "",
      "flight": {
        "number": "1300",
        "iata": "PZ1300",
        "icao": "LAP1300",
        "carrier": {
          "name": "LATAM Paraguay",
          "iata": "PZ",
          "icao": "LAP",
          "logo": "https://content.airhex.com/content/logos/airlines_LAP_250_70_r.png?md5apikey=4b314e33ec57302492ae68c69ca23ff8",
          "tail": "https://content.airhex.com/content/logos/airlines_LAP_70_70_t.png?md5apikey=40828e9cb8074750d69b1eab5d55e89c"
        }
      },
      "code_shares": [
        {
          "number": "1300",
          "iata": "LA1300",
          "icao": "LAN1300",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        }
      ]
    },
    {
      "location": "Campo Grande",
      "time": "2024-02-07T16:40:00-03:00",
      "estimated_time": "2024-02-07T16:40:00-03:00",
      "status": "Scheduled",
      "terminal": "2",
      "gate": "216",
      "flight": {
        "number": "1422",
        "iata": "G31422",
        "icao": "GLO1422",
        "carrier": {
          "name": "Gol Transportes Aereos",
          "iata": "G3",
          "icao": "GLO",
          "logo": "https://content.airhex.com/content/logos/airlines_GLO_250_70_r.png?md5apikey=c4b6396e2accee41e79951b516bd07c5",
          "tail": "https://content.airhex.com/content/logos/airlines_GLO_70_70_t.png?md5apikey=f12d8358a2e9a0abfb5b6627fe0efe63"
        }
      },
      "code_shares": [
        {
          "number": "2371",
          "iata": "UX2371",
          "icao": "AEA2371",
          "carrier": {
            "name": "Air Europa",
            "iata": "UX",
            "icao": "AEA",
            "logo": "https://content.airhex.com/content/logos/airlines_AEA_250_70_r.png?md5apikey=fbb7dcad42fc78003b5ee23c1c1fb7cf",
            "tail": "https://content.airhex.com/content/logos/airlines_AEA_70_70_t.png?md5apikey=5649a3090f42745bd20389192c0a44c7"
          }
        },
        {
          "number": "8163",
          "iata": "AM8163",
          "icao": "AMX8163",
          "carrier": {
            "name": "AeroM\u00e9xico",
            "iata": "AM",
            "icao": "AMX",
            "logo": "https://content.airhex.com/content/logos/airlines_AMX_250_70_r.png?md5apikey=ae35df8024b0ae2214ecca252cada510",
            "tail": "https://content.airhex.com/content/logos/airlines_AMX_70_70_t.png?md5apikey=94b08956e269ba7e9f3f7446b1ce2a2d"
          }
        },
        {
          "number": "7632",
          "iata": "AR7632",
          "icao": "ARG7632",
          "carrier": {
            "name": "Aerolineas Argentinas",
            "iata": "AR",
            "icao": "ARG",
            "logo": "https://content.airhex.com/content/logos/airlines_ARG_250_70_r.png?md5apikey=ce98937e4fb946018be43b9a3c59d9c5",
            "tail": "https://content.airhex.com/content/logos/airlines_ARG_70_70_t.png?md5apikey=aa1e87abfff5120cc4bc70ca44d72cde"
          }
        },
        {
          "number": "3606",
          "iata": "CM3606",
          "icao": "CMP3606",
          "carrier": {
            "name": "Copa Airlines",
            "iata": "CM",
            "icao": "CMP",
            "logo": "https://content.airhex.com/content/logos/airlines_CMP_250_70_r.png?md5apikey=cf5a6f46832bd2a6557c2b827973cd71",
            "tail": "https://content.airhex.com/content/logos/airlines_CMP_70_70_t.png?md5apikey=9cf5fae85062bd85cf458a1a257baeb1"
          }
        },
        {
          "number": "4075",
          "iata": "TP4075",
          "icao": "TAP4075",
          "carrier": {
            "name": "TAP Air Portugal",
            "iata": "TP",
            "icao": "TAP",
            "logo": "https://content.airhex.com/content/logos/airlines_TAP_250_70_r.png?md5apikey=b1bb5bc624a196bcf264e3ecdad6ed97",
            "tail": "https://content.airhex.com/content/logos/airlines_TAP_70_70_t.png?md5apikey=bf762afdab016c637b7c049a1880f2b8"
          }
        }
      ]
    },
    {
      "location": "Rio de Janeiro-Gale\u00e3o International Airport",
      "time": "2024-02-07T16:55:00-03:00",
      "estimated_time": "2024-02-07T16:55:00-03:00",
      "status": "Scheduled",
      "terminal": "2",
      "gate": "",
      "flight": {
        "number": "3475",
        "iata": "JJ3475",
        "icao": "TAM3475",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "8522",
          "iata": "AM8522",
          "icao": "AMX8522",
          "carrier": {
            "name": "AeroM\u00e9xico",
            "iata": "AM",
            "icao": "AMX",
            "logo": "https://content.airhex.com/content/logos/airlines_AMX_250_70_r.png?md5apikey=ae35df8024b0ae2214ecca252cada510",
            "tail": "https://content.airhex.com/content/logos/airlines_AMX_70_70_t.png?md5apikey=94b08956e269ba7e9f3f7446b1ce2a2d"
          }
        },
        {
          "number": "6716",
          "iata": "DL6716",
          "icao": "DAL6716",
          "carrier": {
            "name": "Delta",
            "iata": "DL",
            "icao": "DAL",
            "logo": "https://content.airhex.com/content/logos/airlines_DAL_250_70_r.png?md5apikey=a44c2ef322f43a505da3b6654cf6bff5",
            "tail": "https://content.airhex.com/content/logos/airlines_DAL_70_70_t.png?md5apikey=c7d4aa0c4e033883b5bf572cd2e7875c"
          }
        },
        {
          "number": "3475",
          "iata": "LA3475",
          "icao": "LAN3475",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "4847",
          "iata": "QR4847",
          "icao": "QTR4847",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        },
        {
          "number": "7252",
          "iata": "QR7252",
          "icao": "QTR7252",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        }
      ]
    },
    {
      "location": "Ribeir\u00e3o Preto",
      "time": "2024-02-07T16:55:00-03:00",
      "estimated_time": "2024-02-07T16:55:00-03:00",
      "status": "Scheduled",
      "terminal": "2",
      "gate": "202",
      "flight": {
        "number": "2215",
        "iata": "JJ2215",
        "icao": "TAM2215",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "2215",
          "iata": "2Z2215",
          "icao": "PTB2215",
          "carrier": {
            "name": "Voepass Linhas A\u00e9reas",
            "iata": "2Z",
            "icao": "PTB",
            "logo": "https://content.airhex.com/content/logos/airlines_PTB_250_70_r.png?md5apikey=de629c273406e8aabc6271d0be1c6ab7",
            "tail": "https://content.airhex.com/content/logos/airlines_PTB_70_70_t.png?md5apikey=8c67f52e845e0dafefd59c4e8ca3aeb5"
          }
        }
      ]
    },
    {
      "location": "Vit\u00f3ria da Conquista",
      "time": "2024-02-07T17:00:00-03:00",
      "estimated_time": "2024-02-07T17:00:00-03:00",
      "status": "Scheduled",
      "terminal": "",
      "gate": "",
      "flight": {
        "number": "3238",
        "iata": "JJ3238",
        "icao": "TAM3238",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "3238",
          "iata": "LA3238",
          "icao": "LAN3238",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "7290",
          "iata": "QR7290",
          "icao": "QTR7290",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        }
      ]
    },
    {
      "location": "Natal",
      "time": "2024-02-07T17:00:00-03:00",
      "estimated_time": "2024-02-07T17:00:00-03:00",
      "status": "Scheduled",
      "terminal": "",
      "gate": "",
      "flight": {
        "number": "1370",
        "iata": "G31370",
        "icao": "GLO1370",
        "carrier": {
          "name": "Gol Transportes Aereos",
          "iata": "G3",
          "icao": "GLO",
          "logo": "https://content.airhex.com/content/logos/airlines_GLO_250_70_r.png?md5apikey=c4b6396e2accee41e79951b516bd07c5",
          "tail": "https://content.airhex.com/content/logos/airlines_GLO_70_70_t.png?md5apikey=f12d8358a2e9a0abfb5b6627fe0efe63"
        }
      },
      "code_shares": [
        {
          "number": "4645",
          "iata": "AV4645",
          "icao": "AVA4645",
          "carrier": {
            "name": "Avianca",
            "iata": "AV",
            "icao": "AVA",
            "logo": "https://content.airhex.com/content/logos/airlines_AVA_250_70_r.png?md5apikey=a4da4032c6fdbb8293a9061e352cdc1d",
            "tail": "https://content.airhex.com/content/logos/airlines_AVA_70_70_t.png?md5apikey=a061e5b9cc2f366fe9c6543198498c78"
          }
        },
        {
          "number": "3716",
          "iata": "CM3716",
          "icao": "CMP3716",
          "carrier": {
            "name": "Copa Airlines",
            "iata": "CM",
            "icao": "CMP",
            "logo": "https://content.airhex.com/content/logos/airlines_CMP_250_70_r.png?md5apikey=cf5a6f46832bd2a6557c2b827973cd71",
            "tail": "https://content.airhex.com/content/logos/airlines_CMP_70_70_t.png?md5apikey=9cf5fae85062bd85cf458a1a257baeb1"
          }
        },
        {
          "number": "5754",
          "iata": "TP5754",
          "icao": "TAP5754",
          "carrier": {
            "name": "TAP Air Portugal",
            "iata": "TP",
            "icao": "TAP",
            "logo": "https://content.airhex.com/content/logos/airlines_TAP_250_70_r.png?md5apikey=b1bb5bc624a196bcf264e3ecdad6ed97",
            "tail": "https://content.airhex.com/content/logos/airlines_TAP_70_70_t.png?md5apikey=bf762afdab016c637b7c049a1880f2b8"
          }
        }
      ]
    },
    {
      "location": "Buenos Aires - Ministro Pistarini International Airport",
      "time": "2024-02-07T17:00:00-03:00",
      "estimated_time": "2024-02-07T17:20:00-03:00",
      "status": "Scheduled",
      "terminal": "2",
      "gate": "272",
      "flight": {
        "number": "506",
        "iata": "ET506",
        "icao": "ETH506",
        "carrier": {
          "name": "Ethiopian Airlines",
          "iata": "ET",
          "icao": "ETH",
          "logo": "https://content.airhex.com/content/logos/airlines_ETH_250_70_r.png?md5apikey=3989d8672d7e0695be949c41d4e947e4",
          "tail": "https://content.airhex.com/content/logos/airlines_ETH_70_70_t.png?md5apikey=ea10182db5b1961228b04ebfb766950c"
        }
      },
      "code_shares": []
    },
    {
      "location": "Porto Seguro",
      "time": "2024-02-07T17:05:00-03:00",
      "estimated_time": "2024-02-07T17:05:00-03:00",
      "status": "Scheduled",
      "terminal": "",
      "gate": "",
      "flight": {
        "number": "3244",
        "iata": "JJ3244",
        "icao": "TAM3244",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "3244",
          "iata": "LA3244",
          "icao": "LAN3244",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "5128",
          "iata": "QR5128",
          "icao": "QTR5128",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        }
      ]
    }
  ],
  "arrivals": [
    {
      "location": "Rio de Janeiro-Gale\u00e3o International Airport",
      "time": "2024-02-07T15:10:00-03:00",
      "estimated_time": "2024-02-07T15:08:00-03:00",
      "status": "Taxiing",
      "terminal": "2",
      "gate": "",
      "flight": {
        "number": "3530",
        "iata": "JJ3530",
        "icao": "TAM3530",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "3530",
          "iata": "LA3530",
          "icao": "LAN3530",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "4832",
          "iata": "QR4832",
          "icao": "QTR4832",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        },
        {
          "number": "4836",
          "iata": "QR4836",
          "icao": "QTR4836",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        }
      ]
    },
    {
      "location": "Ribeir\u00e3o Preto",
      "time": "2024-02-07T15:50:00-03:00",
      "estimated_time": "2024-02-07T15:50:00-03:00",
      "status": "Scheduled",
      "terminal": "2",
      "gate": "",
      "flight": {
        "number": "2214",
        "iata": "JJ2214",
        "icao": "TAM2214",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "2214",
          "iata": "2Z2214",
          "icao": "PTB2214",
          "carrier": {
            "name": "Voepass Linhas A\u00e9reas",
            "iata": "2Z",
            "icao": "PTB",
            "logo": "https://content.airhex.com/content/logos/airlines_PTB_250_70_r.png?md5apikey=de629c273406e8aabc6271d0be1c6ab7",
            "tail": "https://content.airhex.com/content/logos/airlines_PTB_70_70_t.png?md5apikey=8c67f52e845e0dafefd59c4e8ca3aeb5"
          }
        }
      ]
    },
    {
      "location": "Lima",
      "time": "2024-02-07T16:20:00-03:00",
      "estimated_time": "2024-02-07T17:24:00-03:00",
      "status": "Delayed",
      "terminal": "3",
      "gate": "",
      "flight": {
        "number": "8040",
        "iata": "JJ8040",
        "icao": "TAM8040",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "6124",
          "iata": "DL6124",
          "icao": "DAL6124",
          "carrier": {
            "name": "Delta",
            "iata": "DL",
            "icao": "DAL",
            "logo": "https://content.airhex.com/content/logos/airlines_DAL_250_70_r.png?md5apikey=a44c2ef322f43a505da3b6654cf6bff5",
            "tail": "https://content.airhex.com/content/logos/airlines_DAL_70_70_t.png?md5apikey=c7d4aa0c4e033883b5bf572cd2e7875c"
          }
        },
        {
          "number": "7380",
          "iata": "DL7380",
          "icao": "DAL7380",
          "carrier": {
            "name": "Delta",
            "iata": "DL",
            "icao": "DAL",
            "logo": "https://content.airhex.com/content/logos/airlines_DAL_250_70_r.png?md5apikey=a44c2ef322f43a505da3b6654cf6bff5",
            "tail": "https://content.airhex.com/content/logos/airlines_DAL_70_70_t.png?md5apikey=c7d4aa0c4e033883b5bf572cd2e7875c"
          }
        },
        {
          "number": "8040",
          "iata": "LA8040",
          "icao": "LAN8040",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "5209",
          "iata": "QR5209",
          "icao": "QTR5209",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        },
        {
          "number": "9762",
          "iata": "LX9762",
          "icao": "SWR9762",
          "carrier": {
            "name": "Swiss",
            "iata": "LX",
            "icao": "SWR",
            "logo": "https://content.airhex.com/content/logos/airlines_SWR_250_70_r.png?md5apikey=ef07165baa14865d3f421bac26f65930",
            "tail": "https://content.airhex.com/content/logos/airlines_SWR_70_70_t.png?md5apikey=5d03b5a8ea5c8599fb3a1698e4bc13f2"
          }
        }
      ]
    },
    {
      "location": "Passo Fundo",
      "time": "2024-02-07T16:20:00-03:00",
      "estimated_time": "2024-02-07T16:20:00-03:00",
      "status": "Scheduled",
      "terminal": "",
      "gate": "",
      "flight": {
        "number": "3403",
        "iata": "JJ3403",
        "icao": "TAM3403",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "3403",
          "iata": "LA3403",
          "icao": "LAN3403",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "5121",
          "iata": "QR5121",
          "icao": "QTR5121",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        },
        {
          "number": "5170",
          "iata": "QR5170",
          "icao": "QTR5170",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        }
      ]
    },
    {
      "location": "Vit\u00f3ria",
      "time": "2024-02-07T16:25:00-03:00",
      "estimated_time": "2024-02-07T16:25:00-03:00",
      "status": "Taxiing",
      "terminal": "2",
      "gate": "",
      "flight": {
        "number": "3333",
        "iata": "JJ3333",
        "icao": "TAM3333",
        "carrier": {
          "name": "LATAM Brasil",
          "iata": "JJ",
          "icao": "TAM",
          "logo": "https://content.airhex.com/content/logos/airlines_TAM_250_70_r.png?md5apikey=cb0ce82c61b008e3ab6d27c019f87a0f",
          "tail": "https://content.airhex.com/content/logos/airlines_TAM_70_70_t.png?md5apikey=a3be93d8ca62e3d00f4363cbc6ef848c"
        }
      },
      "code_shares": [
        {
          "number": "6127",
          "iata": "DL6127",
          "icao": "DAL6127",
          "carrier": {
            "name": "Delta",
            "iata": "DL",
            "icao": "DAL",
            "logo": "https://content.airhex.com/content/logos/airlines_DAL_250_70_r.png?md5apikey=a44c2ef322f43a505da3b6654cf6bff5",
            "tail": "https://content.airhex.com/content/logos/airlines_DAL_70_70_t.png?md5apikey=c7d4aa0c4e033883b5bf572cd2e7875c"
          }
        },
        {
          "number": "6276",
          "iata": "DL6276",
          "icao": "DAL6276",
          "carrier": {
            "name": "Delta",
            "iata": "DL",
            "icao": "DAL",
            "logo": "https://content.airhex.com/content/logos/airlines_DAL_250_70_r.png?md5apikey=a44c2ef322f43a505da3b6654cf6bff5",
            "tail": "https://content.airhex.com/content/logos/airlines_DAL_70_70_t.png?md5apikey=c7d4aa0c4e033883b5bf572cd2e7875c"
          }
        },
        {
          "number": "4705",
          "iata": "LH4705",
          "icao": "DLH4705",
          "carrier": {
            "name": "Lufthansa",
            "iata": "LH",
            "icao": "DLH",
            "logo": "https://content.airhex.com/content/logos/airlines_DLH_250_70_r.png?md5apikey=3c386bbd5275e5997bcdd6434bd7e163",
            "tail": "https://content.airhex.com/content/logos/airlines_DLH_70_70_t.png?md5apikey=922e2a45ef5234356efb70991da3853c"
          }
        },
        {
          "number": "3333",
          "iata": "LA3333",
          "icao": "LAN3333",
          "carrier": {
            "name": "LATAM",
            "iata": "LA",
            "icao": "LAN",
            "logo": "https://content.airhex.com/content/logos/airlines_LAN_250_70_r.png?md5apikey=0c2539b5f76558beef49227bbaca0bcf",
            "tail": "https://content.airhex.com/content/logos/airlines_LAN_70_70_t.png?md5apikey=6c8fd45634159ea1f9f2b1ddc26ceaf9"
          }
        },
        {
          "number": "5253",
          "iata": "QR5253",
          "icao": "QTR5253",
          "carrier": {
            "name": "Qatar Airways",
            "iata": "QR",
            "icao": "QTR",
            "logo": "https://content.airhex.com/content/logos/airlines_QTR_250_70_r.png?md5apikey=1ecfadedfbe3e921e528861036ca3e3e",
            "tail": "https://content.airhex.com/content/logos/airlines_QTR_70_70_t.png?md5apikey=13b2f9bf97d345abaca5f996bf02ca9e"
          }
        }
      ]
    },
    {
      "location": "Jo\u00e3o Pessoa",
      "time": "2024-02-07T16:50:00-03:00",
      "estimated_time": "2024-02-07T17:28:17-03:00",
      "status": "Delayed",
      "terminal": "2",
      "gate": "",
      "flight": {
        "number": "1639",
        "iata": "G31639",
        "icao": "GLO1639",
        "carrier": {
          "name": "Gol Transportes Aereos",
          "iata": "G3",
          "icao": "GLO",
          "logo": "https://content.airhex.com/content/logos/airlines_GLO_250_70_r.png?md5apikey=c4b6396e2accee41e79951b516bd07c5",
          "tail": "https://content.airhex.com/content/logos/airlines_GLO_70_70_t.png?md5apikey=f12d8358a2e9a0abfb5b6627fe0efe63"
        }
      },
      "code_shares": [
        {
          "number": "3725",
          "iata": "CM3725",
          "icao": "CMP3725",
          "carrier": {
            "name": "Copa Airlines",
            "iata": "CM",
            "icao": "CMP",
            "logo": "https://content.airhex.com/content/logos/airlines_CMP_250_70_r.png?md5apikey=cf5a6f46832bd2a6557c2b827973cd71",
            "tail": "https://content.airhex.com/content/logos/airlines_CMP_70_70_t.png?md5apikey=9cf5fae85062bd85cf458a1a257baeb1"
          }
        },
        {
          "number": "9341",
          "iata": "KL9341",
          "icao": "KLM9341",
          "carrier": {
            "name": "KLM",
            "iata": "KL",
            "icao": "KLM",
            "logo": "https://content.airhex.com/content/logos/airlines_KLM_250_70_r.png?md5apikey=a315bf03b89d64d85db386f7a47ba544",
            "tail": "https://content.airhex.com/content/logos/airlines_KLM_70_70_t.png?md5apikey=08ffa80a7c3efba62650c4616bde8dc1"
          }
        },
        {
          "number": "5764",
          "iata": "TP5764",
          "icao": "TAP5764",
          "carrier": {
            "name": "TAP Air Portugal",
            "iata": "TP",
            "icao": "TAP",
            "logo": "https://content.airhex.com/content/logos/airlines_TAP_250_70_r.png?md5apikey=b1bb5bc624a196bcf264e3ecdad6ed97",
            "tail": "https://content.airhex.com/content/logos/airlines_TAP_70_70_t.png?md5apikey=bf762afdab016c637b7c049a1880f2b8"
          }
        }
      ]
    },
    {
      "location": "Cochabamba",
      "time": "2024-02-07T17:25:00-03:00",
      "estimated_time": "2024-02-07T18:20:00-03:00",
      "status": "Delayed",
      "terminal": "2",
      "gate": "",
      "flight": {
        "number": "738",
        "iata": "OB738",
        "icao": "BOV738",
        "carrier": {
          "name": "Boliviana de Aviaci\u00f3n",
          "iata": "OB",
          "icao": "BOV",
          "logo": "https://content.airhex.com/content/logos/airlines_BOV_250_70_r.png?md5apikey=82418c28de871c666b5baade66fc479d",
          "tail": "https://content.airhex.com/content/logos/airlines_BOV_70_70_t.png?md5apikey=321258b35093b4138327265a2c710d56"
        }
      },
      "code_shares": []
    },
    {
      "location": "Dubai International Airport",
      "time": "2024-02-07T17:35:00-03:00",
      "estimated_time": "2024-02-07T18:05:00-03:00",
      "status": "Delayed",
      "terminal": "3",
      "gate": "",
      "flight": {
        "number": "261",
        "iata": "EK261",
        "icao": "UAE261",
        "carrier": {
          "name": "Emirates",
          "iata": "EK",
          "icao": "UAE",
          "logo": "https://content.airhex.com/content/logos/airlines_UAE_250_70_r.png?md5apikey=6e3334b9dd1a5d05ddadd6447eed4eac",
          "tail": "https://content.airhex.com/content/logos/airlines_UAE_70_70_t.png?md5apikey=d25c2e64be2667fe69a48120d512c778"
        }
      },
      "code_shares": [
        {
          "number": "5406",
          "iata": "GF5406",
          "icao": "GFA5406",
          "carrier": {
            "name": "Gulf Air",
            "iata": "GF",
            "icao": "GFA",
            "logo": "https://content.airhex.com/content/logos/airlines_GFA_250_70_r.png?md5apikey=6294e5d93acba6318e7d7a2b8006f697",
            "tail": "https://content.airhex.com/content/logos/airlines_GFA_70_70_t.png?md5apikey=f272b4d6f673d4cf1e03c27fe56d9c07"
          }
        }
      ]
    }
  ]
}
"""
